#=============================================================================
#=============================LOAD THIS PLEASE================================
#=============================================================================

#R has loadable packages that give you extra functions.
#install them using the package installer
#load them by using the library command 
library(MASS)

#=============================================================================
#============================THE ALMIGHTY T-TEST==============================
#=============================================================================


#it slices, it dices, it can probably get you through any and every single
#project during grad school...



#=============================================================================
#===============THE T-TEST ASSUMES TWO NORMAL DISTRIBUTIONS===================
#=============================================================================

#simulating normal data
x=rnorm(1000,5,1) #1000 data points with a mean of 5 and a sd of 1
y=rnorm(20,5,1)

#plots histograms
par(mfrow=c(2,1))
truehist(x,h=0.1,xlim=c(0,10),prob=FALSE)

truehist(y,h=0.1,xlim=c(0,10),prob=FALSE)


boxplot(x,y,ylab ='% alcohol per keg',names = c("existing (n=1000)","new batch n=20"))
print(t.test(x,y))

#=============================================================================
#================APPROPRIATE FOR SMALL SAMPLE SIZES IF...=====================
#=============================================================================
#simulating normal data
x=rnorm(1000,5,1) #1000 data points with a mean of 5 and a sd of 1
y=rnorm(20,5,1)
y = c(y,1000) #adding a ridiculous outlier

dev.off()
boxplot(x,y,ylab ='% alcohol per keg',names = c("existing (n=1000)","new batch n=20"))
print(t.test(x,y))


y = c(y,1000,500,800) #adding a few more outliers
boxplot(x,y,ylab ='% alcohol per keg',names = c("existing (n=1000)","new batch n=20"))
print(t.test(x,y))



#=============================================================================
#=======================DETECTS CHANGES IN THE MEAN===========================
#=============================================================================
#start w/ 2 equal distributions and then slowly increase mean of y
par(mfrow=c(5,2))
shift = 0.1 #shift 10% of the mean each time
for(i in 0:4){
	x=rnorm(1000,5,1)
	y=rnorm(1000,5*(1+shift*i),1)
	truehist(x,h=0.5,xlim=c(0,12),prob=FALSE,col='red')

	truehist(y,h=0.5,xlim=c(0,12),prob=FALSE)
	abline(v=mean(y),col='blue',lwd=2)
	print(paste('mean shift of',i*shift*100,'%'))
	print(t.test(x,y)$p.value)
	
}

#=============================================================================
#=============================BUT NOT SD======================================
#=============================================================================


par(mfrow=c(5,2))
shift = 0.1 #shift 10% of the sd each time
for(i in 0:4){
	x=rnorm(1000,5,1)
	y=rnorm(1000,5,1*(1+shift*i))
	truehist(x,h=0.5,xlim=c(0,12),prob=FALSE,col='red')

	truehist(y,h=0.5,xlim=c(0,12),prob=FALSE)
	abline(v=mean(y),col='blue',lwd=2)
	print(paste('sd shift of',i*shift*100,'%'))
	print(t.test(x,y)$p.value)
	
}

#=============================================================================
#======================CAN BE 1 TAILED OR 2 TAILED============================
#=============================================================================

#is mean of y > x?
x=rnorm(1000,5,1)
y=rnorm(1000,6,1)

t.test(x,y,alternative='less') #remember alternative is the null hypothesis

#is mean of y < x
t.test(x,y,alternative='greater') #remember alternative is the null hypothesis

#same data both times!

#a 1 tailed test has more power (only need to reject 1 side as alternative
x=rnorm(100,5,1)
y=rnorm(100,5.1,1)
t.test(x,y,alternative='less') #remember alternative is the null hypothesis
t.test(x,y,alternative='two.sided') #two sided is the default



#=============================================================================
#=======CAN DETECT SUBTLE BUT SYSTEMATIC CHANGES OF LARGE DISTRIBUTIONS=======
#=============================================================================

#first start w/ small sample size

#start w/ 2 equal distributions and then slowly increase mean of y
shift = 0.02 #shift 2% of the mean each time
for(i in 0:4){
	x=rnorm(50,5,1)
	y=rnorm(50,5*(1+shift*i),1)

	print(paste('mean shift of',i*shift*100,'%'))
	print(t.test(x,y)$p.value)
	
}

#now try w/ large sample size
#start w/ 2 equal distributions and then slowly increase mean of y
shift = 0.02 #shift 2% of the mean each time
for(i in 0:4){
	x=rnorm(10000,5,1)
	y=rnorm(10000,5*(1+shift*i),1)

	print(paste('mean shift of',i*shift*100,'%'))
	print(t.test(x,y)$p.value)
	
}


#=============================================================================
#========================EFFECTS OF SAMPLE SIZE===============================
#=============================================================================

#imagine comparing two batches of 20 kegs from the same overall 
#batch (distribution). How often would you erroneously think they came from
#different batches

#single comparison
x=rnorm(20,5,1) 
y=rnorm(20,5,1)

print(t.test(x,y)) #what p-value did you get????

p_vector = c()
for(i in 1:1000){
	
	x=rnorm(20,5,1) 
	y=rnorm(20,5,1)	
	p_vector = c(p_vector,t.test(x,y)$p.value)
	
}

truehist(p_vector,h=0.05,xlim=c(0,1))
print(length(which(p_vector<0.05)))/1000 ~should equal around 0.05

#we just literally re-simulated p-values



#=====================
#==WRITE CODE HERE====
#=====================

#write some code to increase your sample size and see the fraction of
#tests that give a p-value <0.05

#increasing n from 50 to 1000 by 50 at a time

#do we expect the fraction of tests w/ p < 0.05 to change
#as we increase the size of each sample? 


#solution is down here...don't look
for(n in seq(50,1000,50)){ 	
	p_vector = c()
	for(i in 1:1000){
		x=rnorm(n,5,1) 
		y=rnorm(n,5,1)	
		p_vector = c(p_vector,t.test(x,y)$p.value)		
	}
	truehist(p_vector,h=0.05,xlim=c(0,1))
	print(n)
	print(length(which(p_vector<0.05))/1000) #~should equal around 0.05

}



#=====================
#==END OF CODE BLOCK==
#=====================



#=============================================================================
#========================EFFECTS OF NON-NORMALITY=============================
#=============================================================================

x = rbeta(10000,5,2,ncp=1)

y = rbeta(10000,2,5,ncp=1)+0.4


par(mfrow=c(2,1))
truehist(x,h=0.1,xlim=c(0,2),prob=FALSE)

abline(v=mean(x),col='red',lwd=2)

truehist(y,h=0.1,xlim=c(0,2),prob=FALSE)
abline(v=mean(y),col='red',lwd=2)


print(t.test(x,y))

#uh oh!!!!!

#an ECDF illustrates this nicely
dev.off()
plot(ecdf(x),xlim = c(0,1.5),col='red',main ='ECDF of X and Y',ylab='fraction of values',xlab='values')
lines(ecdf(y),col='blue')
legend(0.2,.7,c('x','y'),col=c('red','blue'),lwd=2)

#=============================================================================
#============================TAKE HOME RULES==================================
#=============================================================================

#1. tests if two samples are drawn from distributions with the same MEAN (not SD)
#2. Use 1 tailed when the question is directional (e.g. does gene go up as 
#opposed to does the gene change)
#3. if sample size is small (<50) only apply when you can assume normality
#4. otherwise use a non-parametric test (e.g. fisher's)
#5. for large data check that your data look normal