#CHANGING YOUR WORKING DIRECTORY

setwd('YOUR WORKING PATH HERE')




#============================================================
#========================DATA================================
#============================================================

#LOADING THE RPKM TABLE
rpkmTable = read.delim('./MM9_kidney_liver_rpkm.txt')





#============================================================
#=======================BASIC R==============================
#============================================================

#print a number
print(5)

#assign a number to a variable
x = 5

#basic operators
x+5
x*5
x/5
x%%4 #gives you the remainder

#create a vector with 3 elements
x = c(1,2,3)

#adding an element to an existing vector
x = c(x,4)

#combining two vectors
x = c(1,2,3)
y = c(4,5,6)
z = c(x,y)
print(z)



#vector math
x + y
x - y 
x*y
x/y

#making vectors in data ranges
x = 0:10 # 0  to 10

#even numbers from 4 to 14
x = seq(4,14,2)

#figuring out max/min and mean/median/range of a vector
max(x)
min(y)

mean(x)
median(x)
range(x)


#sorting a vector
x= c(5,1,3,10)
x = sort(x) #increasing
print(x)

x= c(5,1,3,10)
x = sort(x,decreasing=TRUE) #decreasing
print(x)

#ordering a vector
x= c(5,1,3,10)
xOrder = order(x,decreasing=TRUE)

#printing the 2nd highest value in a vector
print(x[xOrder[2]])


#============================================================
#=====================TABLE MANIPULATIONS====================
#============================================================

#print the first 5 rows of the table
print(rpkmTable[1:5,])

#print rows 20:25
print(rpkmTable[20:25,])

#getting the number of rows in a table
nrow(rpkmTable)

#saving the number of rows to a variable
x = nrow(rpkmTable)

#getting the number of columns in a table
ncol(rpkmTable)

#getting the dimensions of the table
dim(rpkmTable)

#print the last 5 rows of a table
print(rpkmTable[(nrow(rpkmTable)-5):nrow(rpkmTable),])

#getting the third column of a table
col3 = rpkmTable[,3]

#printing the first 20 rows of the 3rd column
print(col3[1:20])

#getting the 5th row of a table
row5 = rpkmTable[5,]

#getting data fir LIVER_R1

liver_R1 = rpkmTable[,6]
#OR
liver_R1 = rpkmTable$LIVER_R1

#============================================================
#=====================DATA MANIPULATIONS=====================
#============================================================


#printing the mean of the third column
print(mean(col3))
#OR
print(mean(rpkmTable[,3]))

#assigning the median of the third column to a variable
col3Median = median(col3)
#OR
col3Median = median(rpkmTable[,3])

#getting the range of the 3rd column of data
range(col3)

#getting the max of the 3rd column of data
max(col3)
#OR
range(col3)[2]

#finding the length of liver_R1 data
length(liver_R1)

#============================================================
#=====================DATA SEARCHING=========================
#============================================================


#finding the row corresponding to the Actb gene
rowIndex = which(rpkmTable[,2] == 'Actb')
actB_row = rpkmTable[rowIndex,]
#OR

actB_row = rpkmTable[which(rpkmTable$NAME == 'Actb'),]

#finding all rows in which the KIDNEY_R1 expression is greater than 10rpkm
kidney_rows = which(rpkmTable[,3] > 10)

#printing the first five row numbers of rows in which the KIDNEY_R1 expression is greater than 10rpkm
print(kidney_rows[1:5])

#printing all data in table for the first five row numbers of rows in which the KIDNEY_R1 expression is greater than 10rpkm
print(rpkmTable[kidney_rows[1:5],])


#============================================================
#================DATA MANIPULATIONS ADVANCED=================
#============================================================

#finding range of all data
range(rpkmTable[,3:8]) #note this excludes columns that have names and other non numeric string identifiers

#finding the 75th percentile of kidney data replicate 1
quantile(rpkmTable$KIDNEY_R1,c(0.75))

#finding 10% quantiles of kidney data replicate 1
quantile(rpkmTable$KIDNEY_R1,seq(0,1,0.1))

#getting the average expression for each column
col_means = apply(rpkmTable[,3:8],2,mean)


#getting the average kidney expression for each gene
kidney_means = apply(rpkmTable[,3:5],1,mean)

#getting the average liver expression for each gene
liver_means = apply(rpkmTable[,6:8],1,mean)

#============================================================
#======================BASIC PLOTTING========================
#============================================================

#SCATTER PLOTS
#NOTE: most plotting options apply to all kinds of plots

#plotting KIDNEY replicate 1 versus replicate 2 rpkm on a scatter
plot(rpkmTable[,3],rpkmTable[,4],xlab='KIDNEY_R1',ylab='KIDNEY_R2')

#setting the xy axis limits
plot(rpkmTable[,3],rpkmTable[,4],xlab='KIDNEY_R1',ylab='KIDNEY_R2',xlim = c(1,3000),ylim = c(1,3000))  #xlim and #ylim allow you to specify 

#changing the dots to blue
plot(rpkmTable[,3],rpkmTable[,4],xlab='KIDNEY_R1',ylab='KIDNEY_R2',xlim = c(1,3000),ylim = c(1,3000),col='blue')

#making the dots solid
plot(rpkmTable[,3],rpkmTable[,4],xlab='KIDNEY_R1',ylab='KIDNEY_R2',xlim = c(1,3000),ylim = c(1,3000),col='blue',pch=19)  #pch option changes the plot symbol

#switching to a log axis
plot(rpkmTable[,3],rpkmTable[,4],xlab='KIDNEY_R1',ylab='KIDNEY_R2',xlim = c(1,3000),ylim = c(1,3000),col='blue',pch=19,log='xy')  #pch option changes the plot symbol

#adding a diagonal line
plot(rpkmTable[,3],rpkmTable[,4],xlab='KIDNEY_R1',ylab='KIDNEY_R2',xlim = c(1,3000),ylim = c(1,3000),col='blue',pch=19,log='xy')  #pch option changes the plot symbol
lines(c(1,3000),c(1,3000))

#making the line thicker and the dots smaller
plot(rpkmTable[,3],rpkmTable[,4],xlab='KIDNEY_R1',ylab='KIDNEY_R2',xlim = c(1,3000),ylim = c(1,3000),col='blue',pch=19,log='xy',cex=0.5)  #cex changes symbol size by a factor 
lines(c(1,3000),c(1,3000),lwd=2)

#adding a title
plot(rpkmTable[,3],rpkmTable[,4],xlab='KIDNEY_R1',ylab='KIDNEY_R2',xlim = c(1,3000),ylim = c(1,3000),col='blue',pch=19,log='xy',cex=0.5,main='MOUSE KIDNEY RPKM')  #main is the title
lines(c(1,3000),c(1,3000),lwd=2)

#exporting as a pdf
#note, more points=  bigger pdfs!!!!
pdf(file='kidney_scatter.pdf',width = 4,height =4) #units are in inches
plot(rpkmTable[,3],rpkmTable[,4],xlab='KIDNEY_R1',ylab='KIDNEY_R2',xlim = c(1,3000),ylim = c(1,3000),col='blue',pch=19,log='xy',cex=0.5,main='MOUSE KIDNEY RPKM')  #main is the title
lines(c(1,3000),c(1,3000),lwd=2)
dev.off() # THIS tells R to finish up and make the file  everything between pdf(...) and dev.off() gets plotted


#exporting as a png
#note, no longer a vector image meaning you can't edit it in illustrator
png(filename='kidney_scatter.png',width = 400,height =400,pointsize = 14) #units are in points. pointsize changes the fontsize. note the file name variable changed from 'file' to 'filename'  this is because R can be stupid.
plot(rpkmTable[,3],rpkmTable[,4],xlab='KIDNEY_R1',ylab='KIDNEY_R2',xlim = c(1,3000),ylim = c(1,3000),col='blue',pch=19,log='xy',cex=0.5,main='MOUSE KIDNEY RPKM')  #main is the title
lines(c(1,3000),c(1,3000),lwd=2)
dev.off() # THIS tells R to finish up and make the file  everything between pdf(...) and dev.off() gets plotted


#BOX PLOTS

#plotting the distribution of all data
boxplot(rpkmTable[,3:8])

#changing the axis to something relevant
boxplot(rpkmTable[,3:8],ylim = c(1,100))

#boxplot of genes that are expressed at > 10rpkm in KIDNEY_R1
kidney_rows = which(rpkmTable[,3] > 10)
boxplot(rpkmTable[kidney_rows,3:8],ylim = c(1,100))

#getting rid of outlier dots
kidney_rows = which(rpkmTable[,3] > 10)
boxplot(rpkmTable[kidney_rows,3:8],ylim = c(1,100),cex=0)

#BAR PLOTS

#plotting the mean expression in each sample
col_means = apply(rpkmTable[,3:8],2,mean)
barplot(col_means,ylab='Mean RPKM')

#coloring kidney red and liver blue
col_means = apply(rpkmTable[,3:8],2,mean)
barplot(col_means,ylab='Mean RPKM',col=c('red','red','red','blue','blue','blue'))


#changing the names of the bars
col_means = apply(rpkmTable[,3:8],2,mean)
barplot(col_means,ylab='Mean RPKM',col=c('red','red','red','blue','blue','blue'),names = c('K1','K2','K3','L1','L2','L3'))

#exporting this plot as a pdf
pdf(file='rpkm_means_bar.pdf',width = 4,height = 6)
col_means = apply(rpkmTable[,3:8],2,mean)
barplot(col_means,ylab='Mean RPKM',col=c('red','red','red','blue','blue','blue'))
dev.off()

#============================================================
#======================BASIC STATISTICS======================
#============================================================

#checking the correlation of replicates

#by pearson correlation
cor(rpkmTable$KIDNEY_R1,rpkmTable$KIDNEY_R2,method= 'pearson')

#by spearman
cor(rpkmTable$KIDNEY_R1,rpkmTable$KIDNEY_R2,method= 'spearman')

#limit only to genes expressed in kidney R1
kidney_rows = which(rpkmTable[,3] > 10)
cor(rpkmTable$KIDNEY_R1[kidney_rows],rpkmTable$KIDNEY_R2[kidney_rows],method= 'pearson')


#checking for differential expression of Actb using a t.test
rowIndex = which(rpkmTable[,2] == 'Actb')
t.test(rpkmTable[rowIndex,3:5],rpkmTable[rowIndex,6:8])

#assigning the p-value to a variable
rowIndex = which(rpkmTable[,2] == 'Actb')
x = t.test(rpkmTable[rowIndex,3:5],rpkmTable[rowIndex,6:8])$p.value

#finding the p-value of differential gene expression for all genes

pValueVector = c()
for(i in 1:nrow(rpkmTable)){
	
	
	pValue = t.test(rpkmTable[i,3:5],rpkmTable[i,6:8])$p.value
	pValueVector = c(pValueVector,pValue)
	
	
}


#finding differentially expressed genes significant below p-value of 0.05
sigGenes = which(pValueVector < 0.05)
sigTable = rpkmTable[sigGenes,]

#plotting a scatter of expression means for differentially expressed genes
plot(kidney_means[sigGenes],liver_means[sigGenes],xlab='KIDNEY',ylab='LIVER',xlim = c(1,3000),ylim = c(1,3000),col='blue',pch=19,log='xy',cex=0.5,main='MOUSE KIDNEY RPKM DIFF GENES')  #main is the title
lines(c(1,3000),c(1,3000),lwd=2)

#finding genes that have a > 2 fold change in either direction
foldchangeVector = log2(kidney_means/liver_means)

twoFoldGenes = which(abs(foldchangeVector) > 1)


#plotting exp changes at genes that change 2 fold or more
plot(kidney_means[twoFoldGenes],liver_means[twoFoldGenes],xlab='KIDNEY',ylab='LIVER',xlim = c(1,3000),ylim = c(1,3000),col='blue',pch=19,log='xy',cex=0.5,main='MOUSE KIDNEY RPKM DIFF GENES')  #main is the title
lines(c(1,3000),c(1,3000),lwd=2)

#getting genes that are significantly differentially expressed AND change 2 fold or more
sigDiffGenes = intersect(sigGenes,twoFoldGenes)

#exporting a scatter of sig diff genes
pdf(file='kidney_liver_sig_scatter.pdf',width = 5,height = 5)
plot(kidney_means[sigDiffGenes],liver_means[sigDiffGenes],xlab='KIDNEY',ylab='LIVER',xlim = c(1,3000),ylim = c(1,3000),col='blue',pch=19,log='xy',cex=0.5,main='MOUSE KIDNEY RPKM DIFF GENES')  #main is the title
lines(c(1,3000),c(1,3000),lwd=2)
dev.off()


#color up genes red and down genes blue
pdf(file='kidney_liver_sig_scatter_colored.pdf',width = 5,height = 5)
#make an empty plot first
plot(1,1,col='white',xlab='KIDNEY',ylab='LIVER',xlim = c(1,3000),ylim = c(1,3000),pch=19,log='xy',cex=0.5,main='MOUSE KIDNEY RPKM DIFF GENES')
upGenes = which(foldchangeVector > 1)
sigDiffGenes = intersect(sigGenes,upGenes)
points(kidney_means[sigDiffGenes],liver_means[sigDiffGenes],cex=0.5, col='red',pch=19)


downGenes = which(foldchangeVector < -1)
sigDiffGenes = intersect(sigGenes,downGenes)
points(kidney_means[sigDiffGenes],liver_means[sigDiffGenes],cex=0.5, col='blue',pch=19)


lines(c(1,3000),c(1,3000),lwd=2)
dev.off()




