#EXPLORING SCREENING DATA


#for this code to work, you must either

#1 use the setwd('/PATH/') command to change the working directory to where the code and data was downloaded
#2 use the "change working directory drop down directory to do the same


#=============================================================================
#============================IMPORT THESE MODULES=============================
#=============================================================================

#load this library that provides some nice stats functions
#by running the next line
library(MASS)

#=============================================================================
#===================INPUTTING A TABLE OF SCREENING RESULTS====================
#=============================================================================

screeningFile = './screening.txt'
screenTable = read.delim(screeningFile)



#=============================================================================
#======================VISUALIZING DISTRIBUTIONS OF ZSCORES===================
#=============================================================================

#which columns have the data
dataColumns = c(2,3) # could notate as 2:3

#histograms

par(mfrow=c(length(dataColumns),1))

for(i in dataColumns){
	
	truehist(screenTable[,i],xlim=c(-20,20),h=.5,xlab='z score',main = colnames(screenTable)[i])
	
}

#cumulative distribution functions

par(mfrow=c(length(dataColumns),1))

for(i in dataColumns){
	
	plot(ecdf(screenTable[,i]),xlim=c(-20,20),xlab='z score',main = colnames(screenTable)[i])
	
}



#=============================================================================
#==============================PLOTTING ZSCORES===============================
#=============================================================================


par(mfrow=c(2,1))
#Plot by screening order (plate order)
plot(1:nrow(screenTable),screenTable[,2],xlab='well position',ylab='z score',pch=16,cex=0.75,col=rgb(0.5,0.5,0.5,0.5))
plot(1:nrow(screenTable),screenTable[,3],xlab='well position',ylab='z score',pch=16,cex=0.75,col=rgb(0.5,0.5,0.5,0.5))






#=============================================================================
#====================USING RANK PLOTS TO IDENTIFY OUTLIERS====================
#=============================================================================




par(mfrow=c(2,1))
rankOrder = order(screenTable[,2],decreasing=FALSE)
plot(1:nrow(screenTable),screenTable[rankOrder,2],xlab='compounds',ylab='z score',pch=16,cex=0.75,col=rgb(0.5,0.5,0.5,0.5),main='Protein A')
rankOrder = order(screenTable[,3],decreasing=FALSE)
plot(1:nrow(screenTable),screenTable[rankOrder,3],xlab='compounds',ylab='z score',pch=16,cex=0.75,col=rgb(0.5,0.5,0.5,0.5),main='Protein B')


#=============================================================================
#==============================PLOTTING HITS==================================
#=============================================================================


cutOff = -5
par(mfrow=c(2,1))

hitVector = which(screenTable[rankOrder,2] < cutOff)
plot(1:nrow(screenTable),screenTable[rankOrder,2],xlab='compounds',ylab='z score',pch=16,cex=0.75,col=rgb(0.5,0.5,0.5,0.5),main='Protein A')
points(1:length(hitVector),screenTable[rankOrder[hitVector],2],pch=16,cex=1.25,col=rgb(1,0,0))

hitVector = which(screenTable[rankOrder,3] < cutOff)
plot(1:nrow(screenTable),screenTable[rankOrder,3],xlab='compounds',ylab='z score',pch=16,cex=0.75,col=rgb(0.5,0.5,0.5,0.5),main='Protein B')
points(1:length(hitVector),screenTable[rankOrder[hitVector],3],pch=16,cex=1.25,col=rgb(1,0,0))


#=============================================================================
#===================COMPARING SCREENING DATA BETWEEN TARGETS==================
#=============================================================================
dev.off()
group1Column = 2
group2Column = 3
plot(screenTable[,group1Column],screenTable[,group2Column],xlab='group1 z score',ylab='group2 z score',pch=16,cex=0.75,col=rgb(0.5,0.5,0.5,0.5))


# a color densitized scatter
smoothScatter(screenTable[,group1Column],screenTable[,group2Column],xlab='group1 z score',ylab='group2 z score',pch=16,cex=0.5,col=rgb(0.5,0.5,0.5,0.5))

#=============================================================================
#===================COMPARING HITS FROM TWO DIFFERENT TARGETS=================
#=============================================================================


group1Column = 2
group2Column = 3

cutOff = -5

group1Hits = which(screenTable[,group1Column] < cutOff)
group2Hits = which(screenTable[,group2Column] < cutOff)

#finding all compounds that hit at least 1 group
allHits = union(group1Hits,group2Hits)

#finding compounds that hit in both groups
bothHits = intersect(group1Hits,group2Hits)

#finding compounds that only hit in group1
group1OnlyHits = setdiff(group1Hits,group2Hits)

#finding compounds that only hit in group2
group2OnlyHits = setdiff(group2Hits,group1Hits)

#plotting screening data w/ hits annotated
plot(screenTable[,group1Column],screenTable[,group2Column],xlab='group1 z score',ylab='group2 z score',pch=16,cex=0.75,col=rgb(0.5,0.5,0.5,0.5))
points(screenTable[bothHits,group1Column],screenTable[bothHits,group2Column],xlab='group1 z score',ylab='group2 z score',pch=19,cex=1,col=rgb(0,0,0,0.5))
points(screenTable[group1OnlyHits,group1Column],screenTable[group1OnlyHits,group2Column],xlab='group1 z score',ylab='group2 z score',pch=19,cex=1,col=rgb(1,0,0,0.5))
points(screenTable[group2OnlyHits,group1Column],screenTable[group2OnlyHits,group2Column],xlab='group1 z score',ylab='group2 z score',pch=19,cex=1,col=rgb(0,0,1,0.5))

