
#for this code to work, you must either

#1 use the setwd('/PATH/') command to change the working directory to where the code and data was downloaded
#2 use the "change working directory drop down directory to do the same


#=============================================================================
#=======================READING IN DATA=======================================
#=============================================================================

expressionTable=read.delim('expression_sample.txt',header=TRUE)

#getting dimensions of the table
print(dim(expressionTable))

#printing first 3 rows to examine format
print(expressionTable[1:3,])


#=============================================================================
#=======================PLOTTING RAW DATA=====================================
#=============================================================================

#getting the names of the columns

names = colnames(expressionTable)

#individual names can be used to extract columns by using the $
print(expressionTable$DMSO_1)

#making pairwise scatter plots
plot(expressionTable$DMSO_1,expressionTable$DRUGA_1)

#log transforming the data
plot(log10(expressionTable$DMSO_1),log10(expressionTable$DRUGA_1))

#setting consistent axis ranges
plot(log10(expressionTable$DMSO_1),log10(expressionTable$DRUGA_1),xlim= c(0,4),ylim = c(0,4))

#making pretty dots
plot(log10(expressionTable$DMSO_1),log10(expressionTable$DRUGA_1),xlim= c(0,4),ylim = c(0,4),pch=19,col=rgb(0,0,1,0.25))

#adding a diagonal
plot(log10(expressionTable$DMSO_1),log10(expressionTable$DRUGA_1),xlim= c(0,4),ylim = c(0,4),pch=19,col=rgb(0,0,1,0.25))
abline(a=0,b=1)


#=============================================================================
#===========================CREATING A DATA MATRIX============================
#=============================================================================

#R allows mixed tables with numeric and character columns
#this is usually a disaster
#easier to make a matrix


#specify which columns have data using : notation
dataColumns = 3:14

expMatrix = as.matrix(expressionTable[,dataColumns])


row.names(expMatrix) = expressionTable[,1]
colnames(expMatrix) = colnames(expressionTable)[3:14]

#=============================================================================
#=======================CHECKING REPLICATE QUALITY============================
#=============================================================================

#look at pairwise comparisons of replicates


#setting a 3x3 plot window
png(filename='DMSO_rep_scatter_norm.png',width =1200,height =1200)
par(mfrow=c(3,3))

#making all pairwise comparisons
for(i in 1:3){
	
	for(j in 1:3){
		
		plot(log10(expMatrix[,i]),log10(expMatrix[,j]),xlim= c(0,4),ylim = c(0,4),pch=19,col=rgb(0,0,0,0.25),xlab= colnames(expMatrix)[i],ylab=colnames(expMatrix)[j])
		lines(0:4,0:4)
		#getting the correlation
		correlation = cor(expMatrix[,i],expMatrix[,j])
		
		text(1,3.5,"pearson")
		text(1,3,round(correlation,4))
		
		
		
	}
		
}
dev.off()

#For DRUGA
#setting a 3x3 plot windowpng
png(filename='DRUGA_rep_scatter_norm.png',width =1200,height =1200)
par(mfrow=c(3,3))

#making all pairwise comparisons
for(i in 4:6){
	
	for(j in 4:6){
		
		plot(log10(expMatrix[,i]),log10(expMatrix[,j]),xlim= c(0,4),ylim = c(0,4),pch=19,col=rgb(0,0,0,0.25),xlab= colnames(expMatrix)[i],ylab=colnames(expMatrix)[j])
		lines(0:4,0:4)
		#getting the correlation
		correlation = cor(expMatrix[,i],expMatrix[,j])
		
		text(1,3.5,"pearson")
		text(1,3,round(correlation,4))
		
		
		
	}
		
}
dev.off()

#=============================================================================
#=======================PLOTTING SCATTER PLOTS OF MEAN========================
#=============================================================================

#dmso vs. DRUGA
dev.off()
group1Label = 'DMSO'
group2Label = 'DRUGA'

group1Columns = c(1,2,3)
group2Columns = c(4,5,6)
group1Means = apply(expMatrix[,group1Columns],1,mean)
group2Means = apply(expMatrix[,group2Columns],1,mean)

plot(log10(group1Means),log10(group2Means),xlim= c(0,4),ylim = c(0,4),pch=19,col=rgb(0,0,0,0.25),xlab= group1Label,ylab=group2Label)
abline(a=0,b=1)



#=============================================================================
#==============IDENTIFYING DIFFERENTIALLY EXPRESSED GENES=====================
#=============================================================================

#identify two groups to compare
group1Label = 'DMSO'
group2Label = 'DRUGA'

group1Columns = c(1,2,3)
group2Columns = c(4,5,6)

#set a significance cutoff
sigCut = 0.05

#set a fold change cutoff (log2) scale
foldCut = 1 

#creates a vector of all of the p-Values
pValueVector = c()
for(i in 1:nrow(expMatrix)){
	
	pValue = t.test(expMatrix[i,group1Columns],expMatrix[i,group2Columns])$p.value
	pValueVector = c(pValueVector,pValue)
	
}

#vector of genes w/ significantly different expression
sigGenes = which(pValueVector < sigCut)

#vector of genes w/ expression fold change greater than cutoff
#absolute value 'abs' here captures by magnitude w/o preference to direction
foldGenes = which(abs(log2(group1Means/group2Means)) > foldCut)

#vector with the row positions of genes that pass fold change and significance cutoffs
sigDiffGenes = intersect(sigGenes,foldGenes)

#expression table of genes w/ sig different expression
sigMatrix = expMatrix[sigDiffGenes,]


#=============================================================================
#=====================SCATTER PLOTS WITH DIFF GENES MARKED====================
#=============================================================================
#use sigDiffGenes from previous section

sigDiffGenes = sigDiffGenes


group1Label = 'DMSO'
group2Label = 'DRUGA'


group1Columns = c(1,2,3)
group2Columns = c(4,5,6)
group1Means = apply(expMatrix[,group1Columns],1,mean)
group2Means = apply(expMatrix[,group2Columns],1,mean)

plot(log10(group1Means),log10(group2Means),xlim= c(0,4),ylim = c(0,4),pch=19,col=rgb(0,0,0,0.25),xlab= group1Label,ylab=group2Label)
abline(a=0,b=1)

points(log10(group1Means[sigDiffGenes]),log10(group2Means[sigDiffGenes]),pch=19,col=rgb(1,0,0))

#=============================================================================
#=======================MAKING HEATMAPS W/ RAW DATA===========================
#=============================================================================

#setting a color spectrum
#blue to red
colorSpectrum <- colorRampPalette(c("blue","white","red"))(100)

#setting a color data range
minValue <- quantile(log10(expMatrix),na.rm=TRUE,prob=0.1,names=FALSE)
maxValue <- quantile(log10(expMatrix),na.rm=TRUE,prob=0.9,names=FALSE)
color_cuts <- seq(minValue,maxValue,length=100)
color_cuts <- c(0, color_cuts,max(log10(expMatrix)))

#add one extra min color to even out sampling
colorSpectrum <- c(colorSpectrum[1],colorSpectrum)


layout(matrix(data=c(1,1,1,1,1,2),nrow=1))
image(1:ncol(log10(expMatrix)),1:nrow(log10(expMatrix)),t(log10(expMatrix)),breaks=color_cuts,col=colorSpectrum,xaxt="n",yaxt="n",xlab="Samples",ylab="Genes")
axis(2,1:93,expressionTable[,1])
axis(3,1:12,colnames(expMatrix))

image(1:2,color_cuts[2:101],t(matrix(data=color_cuts[2:101],ncol=2,nrow=100)),breaks=color_cuts,col=colorSpectrum,xaxt="n",xlab="",ylab="")


#=============================================================================
#===========================CLUSTERING HEATMAP================================
#=============================================================================

d = dist(expMatrix)

hc = hclust(d)
plot(hc)


#setting a color spectrum
#blue to red
colorSpectrum <- colorRampPalette(c("blue","white","red"))(100)

#setting a color data range
minValue <- quantile(log10(expMatrix),na.rm=TRUE,prob=0.1,names=FALSE)
maxValue <- quantile(log10(expMatrix),na.rm=TRUE,prob=0.9,names=FALSE)
color_cuts <- seq(minValue,maxValue,length=100)
color_cuts <- c(0, color_cuts,max(log10(expMatrix)))

#add one extra min color to even out sampling
colorSpectrum <- c(colorSpectrum[1],colorSpectrum)

png(filename ='norm_heat.png',width = 3000,height = 2000,pointsize = 20)
layout(matrix(data=c(1,1,1,1,2,2,2,2,2,2,2,2,2,3,3),nrow=1))
plot(as.dendrogram(hc),horiz=TRUE,leaflab = "none")

image(1:ncol(expMatrix),1:nrow(expMatrix),t(log10(expMatrix[hc$order,])),breaks=color_cuts,col=colorSpectrum,xaxt="n",yaxt="n",xlab="Samples",ylab="Genes")
axis(2,1:nrow(expMatrix[hc$order,]),rownames(expMatrix)[hc$order],las=1)
axis(3,1:12,colnames(expMatrix))

image(1:2,color_cuts[2:101],t(matrix(data=color_cuts[2:101],ncol=2,nrow=100)),breaks=color_cuts,col=colorSpectrum,xaxt="n",xlab="",ylab="")
dev.off()