



#========================================================================
#=======================1. FILL THIS SECTION OUT=========================
#========================================================================


#HOW REPRODUCIBLE IS YOUR DATA?
replicateSD = .2 # (standard deviation of your replicates (log2 fold))

#HOW MUCH OF AN OUTLIER DO YOU WANT TO DETECT?
#this is the true effect
outlier = 0.5 #(log2 absolute fold change)


#HOW MANY REPLICATES DID YOUR BOSS TELL YOU TO DO?
nRep = 3

#YOU'RE GONNA CHANGE THE PVALUE THRESHOLD TO FIT THE DATA, BUT GOTTA START SOMEWHERE
pValueThreshold = 0.01



#========================================================================
#=======================2. LET'S DO 1000 REPLICATES======================
#========================================================================
#WHAT WOULD HAPPEN IF WE DID 1000 REPLICATES?

#IMPORT STATISTICS LIBRARY
library(MASS)

#SIMULATES 1000 replicates
controlMeasurements = rnorm(1000,0,replicateSD)
experimentalMeasurements = rnorm(1000,outlier,replicateSD)


#PLOTS DISTRIBUTIONS OF MEASUREMENTS
par(mfrow=c(2,1))
truehist(controlMeasurements,xlim =c(-5,5),xlab='control measurement',col='grey',prob=FALSE,ylab='# of measurements')

truehist(experimentalMeasurements,xlim =c(-5,5),xlab='experimental measurement',col='red',prob=FALSE,ylab='# of measurements')

#HOW GOOD WERE YOUR MEASUREMENTS AT MEASURING THE TRUE VALUE?

print("ERROR OF CONTROL MEASUREMENT")
print(abs(mean(controlMeasurements)))

print("ERROR OF EXPERIMENTAL MEASUREMENT")
print(abs(mean(experimentalMeasurements)-outlier))

#CAN YOU MEASURE THE EXPERIMENTAL CONDITION AS A STATISTICAL OUTLIER

#RUN THE T TEST ON YOUR CONTROL VS. EXPERIMENTAL MEASUREMENTS
t.test(controlMeasurements,experimentalMeasurements)
print("PROBABILITY THAT THE CONTROL AND EXPERIMENTAL MEASUREMENTS COME FROM THE SAME DISTRIBUTION")
print(t.test(controlMeasurements,experimentalMeasurements)$p.value)


#========================================================================
#======3. UNLESS YOU ARE A ROBOT, YOU CANNOT DO 1,000 REPLICATES=========
#========================================================================

#CLEAR THE PLOTTING CANVAS
dev.off()


#MEASURE ONLY A FEW TIMES
controlMeasurements = rnorm(nRep,0,replicateSD)
experimentalMeasurements = rnorm(nRep,outlier,replicateSD)

#PLOT YOUR MEASUREMENTS
barplot(c(controlMeasurements,experimentalMeasurements),col =c(rep('grey',3),rep('red',3)),ylab='value',main='FEWER REPLICATES')

pValue = t.test(controlMeasurements,experimentalMeasurements)$p.value
print(pValue)

#how many of you got a significant p-value?

#========================================================================
#4. WHAT WOULD HAPPEN IF YOU DID YOUR LOW REPLICATE EXPERIMENT 1000 TIMES
#========================================================================

#CLEAR THE PLOTTING CANVAS
dev.off()


#SIMULATE 1000 EXPERIMENTS AND STORE THE PVALUE
pValues=c()

for(i in 1:1000){
	
	controlMeasurements = rnorm(nRep,0,replicateSD)
	experimentalMeasurements = rnorm(nRep,outlier,replicateSD)
	pValues = c(pValues,t.test(controlMeasurements,experimentalMeasurements)$p.value)
	
	sigFraction = length(which(pValues < pValueThreshold))/length(pValues)
	
	
}

#PLOT THE CDF OF THE PVALUES
plot(ecdf(pValues),ylab='fraction of measurements',main='Distribution of outcomes',xlab='p-value calculated')
abline(v=pValueThreshold)
abline(h=sigFraction)
polygon(c(0,pValueThreshold,pValueThreshold,0),c(0,0,sigFraction,sigFraction),lwd=1,density=-1,col=rgb(1,0,0,0.2))
text(pValueThreshold,sigFraction,sigFraction,adj =c(-1,-1))

#now let's go back and try again looking for a bigger outlier
#this time set outlier to 1
#========================================================================
#==============5. WHAT HAPPENS IF YOU ONLY INCREASE NOISE================
#========================================================================

#LET'S INCREASE NOISE UNTIL IT'S UP BY 10 FOLD

maxNoise = replicateSD*10
noiseVector = seq(replicateSD,maxNoise,length.out=100)
sigFractionVector = c()
for(i in noiseVector ){
	
	pValues = c()
	sampleSigFraction  =c()
	for(j in 1:100){
		controlMeasurements = rnorm(nRep,0,i)
		experimentalMeasurements = rnorm(nRep,outlier,i)
		pValues = c(pValues,t.test(controlMeasurements,experimentalMeasurements)$p.value)
		sigFraction = length(which(pValues < pValueThreshold))/length(pValues)
		sampleSigFraction = c(sampleSigFraction,sigFraction)
	}
	sigFractionVector = c(sigFractionVector,mean(sampleSigFraction))	
	
	
}

plot(noiseVector,sigFractionVector,xlab='SD of measurements',ylab=paste('Probability of detecting outlier at a pValue cutoff of',pValueThreshold),main = paste('Running',nRep,'replicates'))

lines(smooth.spline(noiseVector,sigFractionVector),col='red')


#========================================================================
#===========6. WHAT HAPPENS IF YOU ONLY INCREASE REPLICATES==============
#========================================================================


#LET'S DO TEN TIMES MORE REPLICTES

maxReps = nRep*10
replicateVector = seq(nRep,maxReps,1)
sigFractionVector = c()
for(i in replicateVector ){
	
	pValues = c()
	sampleSigFraction  =c()
	for(j in 1:100){
		controlMeasurements = rnorm(i,0,replicateSD)
		experimentalMeasurements = rnorm(i,outlier,replicateSD)
		pValues = c(pValues,t.test(controlMeasurements,experimentalMeasurements)$p.value)
		sigFraction = length(which(pValues < pValueThreshold))/length(pValues)
		sampleSigFraction = c(sampleSigFraction,sigFraction)
	}
	sigFractionVector = c(sigFractionVector,mean(sampleSigFraction))	
	
	
}

plot(replicateVector,sigFractionVector,xlab='N replicates',ylab=paste('Probability of detecting outlier at a pValue cutoff of',pValueThreshold),main = paste('Running N replicates w/ noise of',replicateSD,'to detect outlier of',outlier,'SD'))

lines(smooth.spline(replicateVector,sigFractionVector),col='red')


#========================================================================
#====================7. VARYING NOISE AND REPLICATES=====================
#========================================================================

replicateVector = seq(2,30,1)

maxNoise = replicateSD*10
noiseVector = seq(0.1,2,length.out=30)


sigMatrix = matrix(nrow=length(replicateVector),ncol=length(noiseVector))



for(i in 1:length(replicateVector)){
	
	reps = replicateVector[i]
	
	for(j in 1:length(noiseVector)){
	
		noise = noiseVector[j]
		pValues = c()
		sampleSigFraction  =c()
		for(n in 1:100){
			controlMeasurements = rnorm(reps,0,noise)
			experimentalMeasurements = rnorm(reps,outlier,noise)
			pValues = c(pValues,t.test(controlMeasurements,experimentalMeasurements)$p.value)
			sigFraction = length(which(pValues < pValueThreshold))/length(pValues)
			sampleSigFraction = c(sampleSigFraction,sigFraction)
		}
		sigMatrix[i,j] = mean(sampleSigFraction)
	}
	
}

colorSpectrum <- colorRampPalette(c("white","white","red"))(100)
#setting a color data range
minValue <- 0
maxValue <- 1
color_cuts <- seq(minValue,maxValue,length=100)
color_cuts = c(color_cuts,1)

layout(matrix(data=c(1,1,1,1,1,2),nrow=1))
image(1:ncol(sigMatrix),1:nrow(sigMatrix),t(sigMatrix),breaks=color_cuts,col=colorSpectrum,xaxt="n",yaxt="n",xlab="Noise (sd)",ylab="Replicates")
axis(1,seq(1,length(noiseVector),5),round(noiseVector[seq(1,length(noiseVector),5)],2))
axis(2,seq(1,length(replicateVector),5),replicateVector[seq(1,length(replicateVector),5)])


image(1:2,color_cuts[2:100],t(matrix(data=color_cuts[2:100],ncol=2,nrow=99)),breaks=color_cuts,col=colorSpectrum,xaxt="n",xlab="",ylab="Outlier detection probability")







